==> jena-3.13.1-source-release.zip: jena-3.13.1/jena-arq/src/test/java/org/apache/jena/sparql/core/mem/TestDatasetGraphInMemoryPromote.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.jena.sparql.core.mem ;

import org.apache.jena.sparql.JenaTransactionException ;
import org.apache.jena.sparql.core.DatasetGraph ;
import org.apache.jena.sparql.transaction.AbstractTestTransPromote ;
import org.apache.log4j.Logger ;

/** Tests for transactions that start read and then promote to write -- TIM */
public class TestDatasetGraphInMemoryPromote extends AbstractTestTransPromote {
    public TestDatasetGraphInMemoryPromote() {
        super(getLoggers()) ;
    }

    @Override
    protected DatasetGraph create() {
        return new DatasetGraphInMemory() ;
    }

    private static Logger[] getLoggers() {
        return new Logger[]{ Logger.getLogger(DatasetGraphInMemory.class) } ;
    }
    
    @Override
    protected Class<JenaTransactionException> getTransactionExceptionClass() {
        return JenaTransactionException.class ;
    }
}

==> jena-5.6.0-source-release.zip: jena-5.6.0/jena-arq/src/test/java/org/apache/jena/sparql/core/mem/TestDatasetGraphInMemoryPromote.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.jena.sparql.core.mem;

import org.apache.jena.sparql.JenaTransactionException;
import org.apache.jena.sparql.core.DatasetGraph;
import org.apache.jena.sparql.transaction.AbstractTestTransPromote;

/** Tests for transactions that start read and then promote to write -- TIM */
public class TestDatasetGraphInMemoryPromote extends AbstractTestTransPromote {
    public TestDatasetGraphInMemoryPromote() {
        super(getLoggers());
    }

    @Override
    protected DatasetGraph create() {
        return new DatasetGraphInMemory();
    }

    private static String[] getLoggers() {
        return new String[]{ DatasetGraphInMemory.class.getName() };
    }

    @Override
    protected Class<JenaTransactionException> getTransactionExceptionClass() {
        return JenaTransactionException.class;
    }
}
